# Components for Kubeflow Pipelines

Kubeflow Pipelines system orchestrates pipeline graphs of containerized command-line programs.
Components are the building blocks of pipelines.
Component definition files describe component interface (inputs and outputs) and implementation (how to call the containerized program).
Users can load components with KFP SDK, instantiate the components and compose them in a pipeline graph.

## Example components

* Python-based: [Train with XGBoost](https://github.com/kubeflow/pipelines/tree/ea94251143f300fafed8950a1b4ba0a6b6065094/components/XGBoost/Train)
* Command-line-based: [Execute notebook](https://github.com/kubeflow/pipelines/blob/329ed48/components/notebooks/Run_notebook_using_papermill/component.yaml)
* Graph-based: [Cross-validate](https://github.com/kubeflow/pipelines/tree/34cb59daaea4f800afae5d968b5efd31eb432291/components/XGBoost/Cross_validation_for_regression/from_CSV)

See how to [build your own components](https://www.kubeflow.org/docs/pipelines/sdk/component-development/).
Also see the tutorials for [data passing for components based on python functions](https://github.com/kubeflow/pipelines/blob/fd5778d/samples/tutorials/Data%20passing%20in%20python%20components.ipynb) and [components based on command-line programs](https://github.com/Ark-kun/kfp_samples/blob/ae1a5b6/2019-10%20Kubeflow%20summit/106%20-%20Creating%20components%20from%20command-line%20programs/106%20-%20Creating%20components%20from%20command-line%20programs.ipynb).

## Index of components
 / [_converters](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters) / [ApacheParquet](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet) / [from_ApacheArrowFeather](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/from_ApacheArrowFeather) / [Convert apache arrow feather to apache parquet](https://raw.githubusercontent.com/kubeflow/pipelines/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/from_ApacheArrowFeather/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters) / [ApacheParquet](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet) / [from_CSV](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/from_CSV) / [Convert csv to apache parquet](https://raw.githubusercontent.com/kubeflow/pipelines/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/from_CSV/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters) / [ApacheParquet](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet) / [from_TSV](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/from_TSV) / [Convert tsv to apache parquet](https://raw.githubusercontent.com/kubeflow/pipelines/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/from_TSV/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters) / [ApacheParquet](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet) / [to_ApacheArrowFeather](https://github.com/kubeflow/pipelines/tree/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/to_ApacheArrowFeather) / [Convert apache parquet to apache arrow feather](https://raw.githubusercontent.com/kubeflow/pipelines/b63dd3f53237f74ae7f965441fd97698fafba7c9/components/_converters/ApacheParquet/to_ApacheArrowFeather/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters) / [ApacheParquet](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters/ApacheParquet) / [to_CSV](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters/ApacheParquet/to_CSV) / [Convert apache parquet to csv](https://raw.githubusercontent.com/kubeflow/pipelines/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters/ApacheParquet/to_CSV/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters) / [ApacheParquet](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters/ApacheParquet) / [to_TSV](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters/ApacheParquet/to_TSV) / [Convert apache parquet to tsv](https://raw.githubusercontent.com/kubeflow/pipelines/cd0e4870e2104c5cda419571938d28533b42167f/components/_converters/ApacheParquet/to_TSV/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/4830e0386ad20693b426838e839b7ebcac6f87d1/components/_converters) / [KerasModelHdf5](https://github.com/kubeflow/pipelines/tree/4830e0386ad20693b426838e839b7ebcac6f87d1/components/_converters/KerasModelHdf5) / [to_TensorflowSavedModel](https://github.com/kubeflow/pipelines/tree/4830e0386ad20693b426838e839b7ebcac6f87d1/components/_converters/KerasModelHdf5/to_TensorflowSavedModel) / [Keras convert hdf5 model to tf saved model](https://raw.githubusercontent.com/kubeflow/pipelines/4830e0386ad20693b426838e839b7ebcac6f87d1/components/_converters/KerasModelHdf5/to_TensorflowSavedModel/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters) / [OnnxModel](https://github.com/kubeflow/pipelines/tree/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters/OnnxModel) / [from_KerasModelHdf5](https://github.com/kubeflow/pipelines/tree/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters/OnnxModel/from_KerasModelHdf5) / [To ONNX from Keras HDF5 model](https://raw.githubusercontent.com/kubeflow/pipelines/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters/OnnxModel/from_KerasModelHdf5/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters) / [OnnxModel](https://github.com/kubeflow/pipelines/tree/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters/OnnxModel) / [from_TensorflowSavedModel](https://github.com/kubeflow/pipelines/tree/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters/OnnxModel/from_TensorflowSavedModel) / [To ONNX from Tensorflow SavedModel](https://raw.githubusercontent.com/kubeflow/pipelines/1aa80685071f0a8800e75a7fbd29dc1df6941293/components/_converters/OnnxModel/from_TensorflowSavedModel/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters) / [TensorflowJSGraphModel](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSGraphModel) / [from_KerasModelHdf5](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSGraphModel/from_KerasModelHdf5) / [Convert Keras HDF5 model to Tensorflow JS GraphModel](https://raw.githubusercontent.com/kubeflow/pipelines/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSGraphModel/from_KerasModelHdf5/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters) / [TensorflowJSGraphModel](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSGraphModel) / [from_TensorflowSavedModel](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSGraphModel/from_TensorflowSavedModel) / [Convert Tensorflow SavedModel to Tensorflow JS GraphModel](https://raw.githubusercontent.com/kubeflow/pipelines/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSGraphModel/from_TensorflowSavedModel/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters) / [TensorflowJSLayersModel](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSLayersModel) / [from_KerasModelHdf5](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSLayersModel/from_KerasModelHdf5) / [Convert Keras HDF5 model to Tensorflow JS LayersModel](https://raw.githubusercontent.com/kubeflow/pipelines/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSLayersModel/from_KerasModelHdf5/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters) / [TensorflowJSLayersModel](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSLayersModel) / [from_TensorflowSavedModel](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSLayersModel/from_TensorflowSavedModel) / [Convert Keras SavedModel to Tensorflow JS LayersModel](https://raw.githubusercontent.com/kubeflow/pipelines/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/_converters/TensorflowJSLayersModel/from_TensorflowSavedModel/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters) / [TensorflowLiteModel](https://github.com/kubeflow/pipelines/tree/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters/TensorflowLiteModel) / [from_KerasModelHdf5](https://github.com/kubeflow/pipelines/tree/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters/TensorflowLiteModel/from_KerasModelHdf5) / [Convert Keras HDF5 model to Tensorflow Lite model](https://raw.githubusercontent.com/kubeflow/pipelines/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters/TensorflowLiteModel/from_KerasModelHdf5/component.yaml)

 / [_converters](https://github.com/kubeflow/pipelines/tree/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters) / [TensorflowLiteModel](https://github.com/kubeflow/pipelines/tree/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters/TensorflowLiteModel) / [from_TensorflowSavedModel](https://github.com/kubeflow/pipelines/tree/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters/TensorflowLiteModel/from_TensorflowSavedModel) / [Convert Tensorflow SavedModel to Tensorflow Lite model](https://raw.githubusercontent.com/kubeflow/pipelines/1802db3a5ba4cbedf70697357fd752929828d9da/components/_converters/TensorflowLiteModel/from_TensorflowSavedModel/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/a3defb13a937c5ec95934321204b709f7d78b937/components/aws) / [athena](https://github.com/kubeflow/pipelines/tree/a3defb13a937c5ec95934321204b709f7d78b937/components/aws/athena) / [query](https://github.com/kubeflow/pipelines/tree/a3defb13a937c5ec95934321204b709f7d78b937/components/aws/athena/query) / [Athena Query](https://raw.githubusercontent.com/kubeflow/pipelines/a3defb13a937c5ec95934321204b709f7d78b937/components/aws/athena/query/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws) / [emr](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr) / [create_cluster](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/create_cluster) / [emr_create_cluster](https://raw.githubusercontent.com/kubeflow/pipelines/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/create_cluster/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws) / [emr](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr) / [delete_cluster](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/delete_cluster) / [emr_delete_cluster](https://raw.githubusercontent.com/kubeflow/pipelines/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/delete_cluster/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws) / [emr](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr) / [submit_pyspark_job](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/submit_pyspark_job) / [emr_submit_pyspark_job](https://raw.githubusercontent.com/kubeflow/pipelines/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/submit_pyspark_job/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws) / [emr](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr) / [submit_spark_job](https://github.com/kubeflow/pipelines/tree/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/submit_spark_job) / [emr_submit_spark_job](https://raw.githubusercontent.com/kubeflow/pipelines/f5c464a87d589d5d542bc4bfe2324ed6bbfa4675/components/aws/emr/submit_spark_job/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [batch_transform](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/batch_transform) / [SageMaker - Batch Transformation](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/batch_transform/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [deploy](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/deploy) / [SageMaker - Deploy Model](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/deploy/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [ground_truth](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/ground_truth) / [SageMaker - Ground Truth](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/ground_truth/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [hyperparameter_tuning](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/hyperparameter_tuning) / [SageMaker - Hyperparameter Tuning](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/hyperparameter_tuning/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [model](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/model) / [SageMaker - Create Model](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/model/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [process](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/process) / [SageMaker - Processing Job](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/process/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [train](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/train) / [SageMaker - Training Job](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/train/component.yaml)

 / [aws](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws) / [sagemaker](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker) / [workteam](https://github.com/kubeflow/pipelines/tree/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/workteam) / [SageMaker - Private Workforce](https://raw.githubusercontent.com/kubeflow/pipelines/d81c8095d0f592b9ba9785f6afadfedf7ccf064a/components/aws/sagemaker/workteam/component.yaml)

 / [azure](https://github.com/kubeflow/pipelines/tree/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure) / [azuredevops](https://github.com/kubeflow/pipelines/tree/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure/azuredevops) / [queue-pipeline](https://github.com/kubeflow/pipelines/tree/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure/azuredevops/queue-pipeline) / [Queue Azure Pipeline](https://raw.githubusercontent.com/kubeflow/pipelines/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure/azuredevops/queue-pipeline/component.yaml)

 / [azure](https://github.com/kubeflow/pipelines/tree/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure) / [azureml](https://github.com/kubeflow/pipelines/tree/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure/azureml) / [aml-register-model](https://github.com/kubeflow/pipelines/tree/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure/azureml/aml-register-model) / [Azure ML Register Model](https://raw.githubusercontent.com/kubeflow/pipelines/210eb8afaae43000cf46a8aec6c17dd3eda3c08f/components/azure/azureml/aml-register-model/component.yaml)

 / [basics](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/basics) / [Calculate_hash](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/basics/Calculate_hash) / [Calculate data hash](https://raw.githubusercontent.com/kubeflow/pipelines/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/basics/Calculate_hash/component.yaml)

 / [CatBoost](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost) / [convert_CatBoostModel_to_AppleCoreMLModel](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/convert_CatBoostModel_to_AppleCoreMLModel) / [Convert CatBoostModel to AppleCoreMLModel](https://raw.githubusercontent.com/kubeflow/pipelines/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/convert_CatBoostModel_to_AppleCoreMLModel/component.yaml)

 / [CatBoost](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost) / [convert_CatBoostModel_to_ONNX](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/convert_CatBoostModel_to_ONNX) / [Convert CatBoostModel to ONNX](https://raw.githubusercontent.com/kubeflow/pipelines/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/convert_CatBoostModel_to_ONNX/component.yaml)

 / [CatBoost](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost) / [Predict_class_probabilities](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_class_probabilities) / [from_CSV](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_class_probabilities/from_CSV) / [Catboost predict class probabilities](https://raw.githubusercontent.com/kubeflow/pipelines/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_class_probabilities/from_CSV/component.yaml)

 / [CatBoost](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost) / [Predict_classes](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_classes) / [from_CSV](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_classes/from_CSV) / [Catboost predict classes](https://raw.githubusercontent.com/kubeflow/pipelines/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_classes/from_CSV/component.yaml)

 / [CatBoost](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost) / [Predict_values](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_values) / [from_CSV](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_values/from_CSV) / [Catboost predict values](https://raw.githubusercontent.com/kubeflow/pipelines/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Predict_values/from_CSV/component.yaml)

 / [CatBoost](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost) / [Train_classifier](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Train_classifier) / [from_CSV](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Train_classifier/from_CSV) / [Catboost train classifier](https://raw.githubusercontent.com/kubeflow/pipelines/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Train_classifier/from_CSV/component.yaml)

 / [CatBoost](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost) / [Train_regression](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Train_regression) / [from_CSV](https://github.com/kubeflow/pipelines/tree/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Train_regression/from_CSV) / [Catboost train regression](https://raw.githubusercontent.com/kubeflow/pipelines/2e9e75039ad14ed002d7ffeae65941932a443d70/components/CatBoost/Train_regression/from_CSV/component.yaml)

 / [dataset_manipulation](https://github.com/kubeflow/pipelines/tree/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/dataset_manipulation) / [split_data_into_folds](https://github.com/kubeflow/pipelines/tree/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/dataset_manipulation/split_data_into_folds) / [in_CSV](https://github.com/kubeflow/pipelines/tree/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/dataset_manipulation/split_data_into_folds/in_CSV) / [Split table into folds](https://raw.githubusercontent.com/kubeflow/pipelines/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/dataset_manipulation/split_data_into_folds/in_CSV/component.yaml)

 / [datasets](https://github.com/kubeflow/pipelines/tree/5e3d9aa791fe684962d16be4f0f767feed6222b2/components/datasets) / [Chicago_Taxi_Trips](https://github.com/kubeflow/pipelines/tree/5e3d9aa791fe684962d16be4f0f767feed6222b2/components/datasets/Chicago_Taxi_Trips) / [Chicago Taxi Trips dataset](https://raw.githubusercontent.com/kubeflow/pipelines/5e3d9aa791fe684962d16be4f0f767feed6222b2/components/datasets/Chicago_Taxi_Trips/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated) / [dataflow](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow) / [predict](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/predict) / [Predict using TF on Dataflow](https://raw.githubusercontent.com/kubeflow/pipelines/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/predict/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated) / [dataflow](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow) / [tfdv](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/tfdv) / [TFX - Data Validation](https://raw.githubusercontent.com/kubeflow/pipelines/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/tfdv/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated) / [dataflow](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow) / [tfma](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/tfma) / [TFX - Analyze model](https://raw.githubusercontent.com/kubeflow/pipelines/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/tfma/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated) / [dataflow](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow) / [tft](https://github.com/kubeflow/pipelines/tree/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/tft) / [Transform using TF on Dataflow](https://raw.githubusercontent.com/kubeflow/pipelines/41dc3865eb053bff4eb77029cd56a7bed2b46f0e/components/deprecated/dataflow/tft/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [Evaluator](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Evaluator) / [Evaluator](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Evaluator/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [Evaluator](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Evaluator) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Evaluator/with_URI_IO) / [Evaluator](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Evaluator/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen) / [BigQueryExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/BigQueryExampleGen) / [BigQueryExampleGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/BigQueryExampleGen/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen) / [BigQueryExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/BigQueryExampleGen) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/BigQueryExampleGen/with_URI_IO) / [BigQueryExampleGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/BigQueryExampleGen/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen) / [CsvExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/CsvExampleGen) / [CsvExampleGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/CsvExampleGen/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen) / [CsvExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/CsvExampleGen) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/CsvExampleGen/with_URI_IO) / [CsvExampleGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/CsvExampleGen/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen) / [ImportExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/ImportExampleGen) / [ImportExampleGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/ImportExampleGen/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen) / [ImportExampleGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/ImportExampleGen) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/ImportExampleGen/with_URI_IO) / [ImportExampleGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleGen/ImportExampleGen/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleValidator](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleValidator) / [ExampleValidator](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleValidator/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [ExampleValidator](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleValidator) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleValidator/with_URI_IO) / [ExampleValidator](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/ExampleValidator/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [SchemaGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/SchemaGen) / [SchemaGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/SchemaGen/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [SchemaGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/SchemaGen) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/SchemaGen/with_URI_IO) / [SchemaGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/SchemaGen/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [StatisticsGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/StatisticsGen) / [StatisticsGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/StatisticsGen/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [StatisticsGen](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/StatisticsGen) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/StatisticsGen/with_URI_IO) / [StatisticsGen](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/StatisticsGen/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [Trainer](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Trainer) / [Trainer](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Trainer/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [Trainer](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Trainer) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Trainer/with_URI_IO) / [Trainer](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Trainer/with_URI_IO/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [Transform](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Transform) / [Transform](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Transform/component.yaml)

 / [deprecated](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated) / [tfx](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx) / [Transform](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Transform) / [with_URI_IO](https://github.com/kubeflow/pipelines/tree/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Transform/with_URI_IO) / [Transform](https://raw.githubusercontent.com/kubeflow/pipelines/5b50de0d39257e31e24fd294ce42153952af0ad0/components/deprecated/tfx/Transform/with_URI_IO/component.yaml)

 / [diagnostics](https://github.com/kubeflow/pipelines/tree/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/diagnostics) / [diagnose_me](https://github.com/kubeflow/pipelines/tree/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/diagnostics/diagnose_me) / [Run diagnose me](https://raw.githubusercontent.com/kubeflow/pipelines/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/diagnostics/diagnose_me/component.yaml)

 / [filesystem](https://github.com/kubeflow/pipelines/tree/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem) / [get_file](https://github.com/kubeflow/pipelines/tree/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem/get_file) / [Get file](https://raw.githubusercontent.com/kubeflow/pipelines/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem/get_file/component.yaml)

 / [filesystem](https://github.com/kubeflow/pipelines/tree/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem) / [get_subdirectory](https://github.com/kubeflow/pipelines/tree/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem/get_subdirectory) / [Get subdirectory](https://raw.githubusercontent.com/kubeflow/pipelines/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem/get_subdirectory/component.yaml)

 / [filesystem](https://github.com/kubeflow/pipelines/tree/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem) / [list_items](https://github.com/kubeflow/pipelines/tree/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem/list_items) / [List items](https://raw.githubusercontent.com/kubeflow/pipelines/9e7e90b97a008ac609b0e69072ed569c42822402/components/filesystem/list_items/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp/automl) / [create_dataset_for_tables](https://github.com/kubeflow/pipelines/tree/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp/automl/create_dataset_for_tables) / [Automl create dataset for tables](https://raw.githubusercontent.com/kubeflow/pipelines/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp/automl/create_dataset_for_tables/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp/automl) / [create_model_for_tables](https://github.com/kubeflow/pipelines/tree/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp/automl/create_model_for_tables) / [Automl create model for tables](https://raw.githubusercontent.com/kubeflow/pipelines/52d59950bdce522d70647b9180eb3072ac3a02d1/components/gcp/automl/create_model_for_tables/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/gcp/automl) / [deploy_model](https://github.com/kubeflow/pipelines/tree/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/gcp/automl/deploy_model) / [Automl deploy model](https://raw.githubusercontent.com/kubeflow/pipelines/b1f46accdfeef67b2ff31e16e10304a6412f6b14/components/gcp/automl/deploy_model/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/6e33c799c2ef477f4b85f0b616ff11da9972278f/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/6e33c799c2ef477f4b85f0b616ff11da9972278f/components/gcp/automl) / [export_data_to_gcs](https://github.com/kubeflow/pipelines/tree/6e33c799c2ef477f4b85f0b616ff11da9972278f/components/gcp/automl/export_data_to_gcs) / [Automl export data to gcs](https://raw.githubusercontent.com/kubeflow/pipelines/6e33c799c2ef477f4b85f0b616ff11da9972278f/components/gcp/automl/export_data_to_gcs/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/d5ae723fdb50968c4da2ba336c52a33d825f2020/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/d5ae723fdb50968c4da2ba336c52a33d825f2020/components/gcp/automl) / [export_model_to_gcs](https://github.com/kubeflow/pipelines/tree/d5ae723fdb50968c4da2ba336c52a33d825f2020/components/gcp/automl/export_model_to_gcs) / [Automl export model to gcs](https://raw.githubusercontent.com/kubeflow/pipelines/d5ae723fdb50968c4da2ba336c52a33d825f2020/components/gcp/automl/export_model_to_gcs/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl) / [import_data_from_bigquery](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl/import_data_from_bigquery) / [Automl import data from bigquery](https://raw.githubusercontent.com/kubeflow/pipelines/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl/import_data_from_bigquery/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl) / [import_data_from_gcs](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl/import_data_from_gcs) / [Automl import data from gcs](https://raw.githubusercontent.com/kubeflow/pipelines/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl/import_data_from_gcs/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/41ce68ea45b8642ed029fba12a8ac4a9e6825ece/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/41ce68ea45b8642ed029fba12a8ac4a9e6825ece/components/gcp/automl) / [prediction_service_batch_predict](https://github.com/kubeflow/pipelines/tree/41ce68ea45b8642ed029fba12a8ac4a9e6825ece/components/gcp/automl/prediction_service_batch_predict) / [Automl prediction service batch predict](https://raw.githubusercontent.com/kubeflow/pipelines/41ce68ea45b8642ed029fba12a8ac4a9e6825ece/components/gcp/automl/prediction_service_batch_predict/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp) / [automl](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl) / [split_dataset_table_column_names](https://github.com/kubeflow/pipelines/tree/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl/split_dataset_table_column_names) / [Automl split dataset table column names](https://raw.githubusercontent.com/kubeflow/pipelines/ee527c8ad4c6fd60e8ee8a37f0653330ed0dc426/components/gcp/automl/split_dataset_table_column_names/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [bigquery](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery) / [query](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery/query) / [to_CSV](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery/query/to_CSV) / [Bigquery - Query](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/bigquery/query/to_CSV/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [bigquery](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery) / [query](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery/query) / [to_gcs](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery/query/to_gcs) / [Bigquery - Query](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/bigquery/query/to_gcs/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [bigquery](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery) / [query](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery/query) / [to_table](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/bigquery/query/to_table) / [Bigquery - Query](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/bigquery/query/to_table/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataflow](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataflow) / [launch_python](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataflow/launch_python) / [Launch Python](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataflow/launch_python/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataflow](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataflow) / [launch_template](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataflow/launch_template) / [Launch Dataflow Template](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataflow/launch_template/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [create_cluster](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/create_cluster) / [dataproc_create_cluster](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/create_cluster/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [delete_cluster](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/delete_cluster) / [dataproc_delete_cluster](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/delete_cluster/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [submit_hadoop_job](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/submit_hadoop_job) / [dataproc_submit_hadoop_job](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/submit_hadoop_job/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [submit_hive_job](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/submit_hive_job) / [dataproc_submit_hive_job](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/submit_hive_job/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [submit_pig_job](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/submit_pig_job) / [dataproc_submit_pig_job](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/submit_pig_job/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [submit_pyspark_job](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/submit_pyspark_job) / [dataproc_submit_pyspark_job](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/submit_pyspark_job/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [submit_spark_job](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/submit_spark_job) / [dataproc_submit_spark_job](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/submit_spark_job/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [dataproc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc) / [submit_sparksql_job](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/dataproc/submit_sparksql_job) / [dataproc_submit_sparksql_job](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/dataproc/submit_sparksql_job/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [ml_engine](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/ml_engine) / [batch_predict](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/ml_engine/batch_predict) / [Batch predict against a model with Cloud ML Engine](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/ml_engine/batch_predict/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [ml_engine](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/ml_engine) / [deploy](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/ml_engine/deploy) / [Deploying a trained model to Cloud Machine Learning Engine](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/ml_engine/deploy/component.yaml)

 / [gcp](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp) / [ml_engine](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/ml_engine) / [train](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/gcp/ml_engine/train) / [Submitting a Cloud ML training job as a pipeline step](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/gcp/ml_engine/train/component.yaml)

 / [git](https://github.com/kubeflow/pipelines/tree/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/git) / [clone](https://github.com/kubeflow/pipelines/tree/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/git/clone) / [Git clone](https://raw.githubusercontent.com/kubeflow/pipelines/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/git/clone/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/a316e1e083614b09479a903ecb9b7382f86ad997/components/google-cloud) / [AutoML](https://github.com/kubeflow/pipelines/tree/a316e1e083614b09479a903ecb9b7382f86ad997/components/google-cloud/AutoML) / [Tables](https://github.com/kubeflow/pipelines/tree/a316e1e083614b09479a903ecb9b7382f86ad997/components/google-cloud/AutoML/Tables) / [Create_dataset](https://github.com/kubeflow/pipelines/tree/a316e1e083614b09479a903ecb9b7382f86ad997/components/google-cloud/AutoML/Tables/Create_dataset) / [from_CSV](https://github.com/kubeflow/pipelines/tree/a316e1e083614b09479a903ecb9b7382f86ad997/components/google-cloud/AutoML/Tables/Create_dataset/from_CSV) / [Automl create tables dataset from csv](https://raw.githubusercontent.com/kubeflow/pipelines/a316e1e083614b09479a903ecb9b7382f86ad997/components/google-cloud/AutoML/Tables/Create_dataset/from_CSV/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud) / [Optimizer](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer) / [Add_measurement_for_trial](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer/Add_measurement_for_trial) / [Add measurement for trial in gcp ai platform optimizer](https://raw.githubusercontent.com/kubeflow/pipelines/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer/Add_measurement_for_trial/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud) / [Optimizer](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer) / [Create_study](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer/Create_study) / [Create study in gcp ai platform optimizer](https://raw.githubusercontent.com/kubeflow/pipelines/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer/Create_study/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/f30aa0975d246e55ee3619ca0d96bd4fdbb27f58/components/google-cloud) / [Optimizer](https://github.com/kubeflow/pipelines/tree/f30aa0975d246e55ee3619ca0d96bd4fdbb27f58/components/google-cloud/Optimizer) / [Suggest_parameter_sets_based_on_measurements](https://github.com/kubeflow/pipelines/tree/f30aa0975d246e55ee3619ca0d96bd4fdbb27f58/components/google-cloud/Optimizer/Suggest_parameter_sets_based_on_measurements) / [Suggest parameter sets from measurements using gcp ai platform optimizer](https://raw.githubusercontent.com/kubeflow/pipelines/f30aa0975d246e55ee3619ca0d96bd4fdbb27f58/components/google-cloud/Optimizer/Suggest_parameter_sets_based_on_measurements/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud) / [Optimizer](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer) / [Suggest_trials](https://github.com/kubeflow/pipelines/tree/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer/Suggest_trials) / [Suggest trials in gcp ai platform optimizer](https://raw.githubusercontent.com/kubeflow/pipelines/b601832157fec7ea914ce5bc063559a1411cc5e1/components/google-cloud/Optimizer/Suggest_trials/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/0ffcbd7ed856ecdd1b7545b6bc378fbc1074096e/components/google-cloud) / [storage](https://github.com/kubeflow/pipelines/tree/0ffcbd7ed856ecdd1b7545b6bc378fbc1074096e/components/google-cloud/storage) / [download](https://github.com/kubeflow/pipelines/tree/0ffcbd7ed856ecdd1b7545b6bc378fbc1074096e/components/google-cloud/storage/download) / [Download from GCS](https://raw.githubusercontent.com/kubeflow/pipelines/0ffcbd7ed856ecdd1b7545b6bc378fbc1074096e/components/google-cloud/storage/download/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud) / [storage](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage) / [download_blob](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/download_blob) / [Download from GCS](https://raw.githubusercontent.com/kubeflow/pipelines/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/download_blob/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud) / [storage](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage) / [download_dir](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/download_dir) / [Download from GCS](https://raw.githubusercontent.com/kubeflow/pipelines/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/download_dir/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/google-cloud) / [storage](https://github.com/kubeflow/pipelines/tree/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/google-cloud/storage) / [list](https://github.com/kubeflow/pipelines/tree/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/google-cloud/storage/list) / [List blobs](https://raw.githubusercontent.com/kubeflow/pipelines/d707b93fb4fb49eaa23a73aacb7caee720c5f8ce/components/google-cloud/storage/list/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud) / [storage](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage) / [upload_to_explicit_uri](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/upload_to_explicit_uri) / [Upload to GCS](https://raw.githubusercontent.com/kubeflow/pipelines/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/upload_to_explicit_uri/component.yaml)

 / [google-cloud](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud) / [storage](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage) / [upload_to_unique_uri](https://github.com/kubeflow/pipelines/tree/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/upload_to_unique_uri) / [Upload to GCS](https://raw.githubusercontent.com/kubeflow/pipelines/2dac60c400ad8767b452649d08f328dfaf230f96/components/google-cloud/storage/upload_to_unique_uri/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/9f6d34ff6559d607f91518259f8d4203c2f58443/components/ibm-components) / [commons](https://github.com/kubeflow/pipelines/tree/9f6d34ff6559d607f91518259f8d4203c2f58443/components/ibm-components/commons) / [config](https://github.com/kubeflow/pipelines/tree/9f6d34ff6559d607f91518259f8d4203c2f58443/components/ibm-components/commons/config) / [Create Secret - Kubernetes Cluster](https://raw.githubusercontent.com/kubeflow/pipelines/9f6d34ff6559d607f91518259f8d4203c2f58443/components/ibm-components/commons/config/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components) / [ffdl](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/ffdl) / [serve](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/ffdl/serve) / [Serve PyTorch Model - Seldon Core](https://raw.githubusercontent.com/kubeflow/pipelines/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/ffdl/serve/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components) / [ffdl](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/ffdl) / [train](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/ffdl/train) / [Train Model - FfDL](https://raw.githubusercontent.com/kubeflow/pipelines/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/ffdl/train/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components) / [spark](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark) / [data_preprocess_spark](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark/data_preprocess_spark) / [Preprocess Data using Spark - IBM Cloud](https://raw.githubusercontent.com/kubeflow/pipelines/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark/data_preprocess_spark/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components) / [spark](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark) / [store_spark_model](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark/store_spark_model) / [Store Spark Model - Watson Machine Learning](https://raw.githubusercontent.com/kubeflow/pipelines/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark/store_spark_model/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components) / [spark](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark) / [train_spark](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark/train_spark) / [Train Spark Model - IBM Cloud](https://raw.githubusercontent.com/kubeflow/pipelines/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/spark/train_spark/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/782eb23488c30f955f3c301123b705b216dc6d0c/components/ibm-components) / [watson](https://github.com/kubeflow/pipelines/tree/782eb23488c30f955f3c301123b705b216dc6d0c/components/ibm-components/watson) / [deploy](https://github.com/kubeflow/pipelines/tree/782eb23488c30f955f3c301123b705b216dc6d0c/components/ibm-components/watson/deploy) / [Deploy Model - Watson Machine Learning](https://raw.githubusercontent.com/kubeflow/pipelines/782eb23488c30f955f3c301123b705b216dc6d0c/components/ibm-components/watson/deploy/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components) / [watson](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson) / [manage](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson/manage) / [monitor_fairness](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson/manage/monitor_fairness) / [Monitor Fairness - Watson OpenScale](https://raw.githubusercontent.com/kubeflow/pipelines/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson/manage/monitor_fairness/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components) / [watson](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson) / [manage](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson/manage) / [monitor_quality](https://github.com/kubeflow/pipelines/tree/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson/manage/monitor_quality) / [Monitor quality - Watson OpenScale](https://raw.githubusercontent.com/kubeflow/pipelines/8418b316f5b4d096fc15109ab90061984217d3ed/components/ibm-components/watson/manage/monitor_quality/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components) / [watson](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/watson) / [manage](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/watson/manage) / [subscribe](https://github.com/kubeflow/pipelines/tree/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/watson/manage/subscribe) / [Subscribe - Watson OpenScale](https://raw.githubusercontent.com/kubeflow/pipelines/121bfdfc5f832948a799a6e93d7c1cd985c5d254/components/ibm-components/watson/manage/subscribe/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components) / [watson](https://github.com/kubeflow/pipelines/tree/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components/watson) / [store](https://github.com/kubeflow/pipelines/tree/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components/watson/store) / [Store model - Watson Machine Learning](https://raw.githubusercontent.com/kubeflow/pipelines/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components/watson/store/component.yaml)

 / [ibm-components](https://github.com/kubeflow/pipelines/tree/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components) / [watson](https://github.com/kubeflow/pipelines/tree/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components/watson) / [train](https://github.com/kubeflow/pipelines/tree/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components/watson/train) / [Train Model - Watson Machine Learning](https://raw.githubusercontent.com/kubeflow/pipelines/de2e0f2ec0edc1afd16ad79d8cd9719d1b01cb1f/components/ibm-components/watson/train/component.yaml)

 / [json](https://github.com/kubeflow/pipelines/tree/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json) / [Build_dict](https://github.com/kubeflow/pipelines/tree/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json/Build_dict) / [Build dict](https://raw.githubusercontent.com/kubeflow/pipelines/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json/Build_dict/component.yaml)

 / [json](https://github.com/kubeflow/pipelines/tree/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json) / [Build_list](https://github.com/kubeflow/pipelines/tree/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json/Build_list) / [Build list](https://raw.githubusercontent.com/kubeflow/pipelines/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json/Build_list/component.yaml)

 / [json](https://github.com/kubeflow/pipelines/tree/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json) / [Combine_lists](https://github.com/kubeflow/pipelines/tree/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json/Combine_lists) / [Combine lists](https://raw.githubusercontent.com/kubeflow/pipelines/616c48babede5cde4ef20b6c35cea24c66b1c44d/components/json/Combine_lists/component.yaml)

 / [json](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json) / [Get_element_by_index](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json/Get_element_by_index) / [Get element by index from JSON](https://raw.githubusercontent.com/kubeflow/pipelines/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json/Get_element_by_index/component.yaml)

 / [json](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json) / [Get_element_by_key](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json/Get_element_by_key) / [Get element by key from JSON](https://raw.githubusercontent.com/kubeflow/pipelines/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json/Get_element_by_key/component.yaml)

 / [json](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json) / [Query](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json/Query) / [Query JSON using JQ](https://raw.githubusercontent.com/kubeflow/pipelines/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/json/Query/component.yaml)

 / [keras](https://github.com/kubeflow/pipelines/tree/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/keras) / [Train_classifier](https://github.com/kubeflow/pipelines/tree/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/keras/Train_classifier) / [from_CSV](https://github.com/kubeflow/pipelines/tree/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/keras/Train_classifier/from_CSV) / [Keras train classifier from csv](https://raw.githubusercontent.com/kubeflow/pipelines/5f7afe3eadf021cfc5316ff3542e4eb66114f2cd/components/keras/Train_classifier/from_CSV/component.yaml)

 / [kubeflow](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/kubeflow) / [deployer](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/kubeflow/deployer) / [Kubeflow - Serve TF model](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/kubeflow/deployer/component.yaml)

 / [kubeflow](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/kubeflow) / [dnntrainer](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/kubeflow/dnntrainer) / [Train FC DNN using TF](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/kubeflow/dnntrainer/component.yaml)

 / [kubeflow](https://github.com/kubeflow/pipelines/tree/d343607674a196eb4ba21a29eb56ecccc5af658a/components/kubeflow) / [katib-launcher](https://github.com/kubeflow/pipelines/tree/d343607674a196eb4ba21a29eb56ecccc5af658a/components/kubeflow/katib-launcher) / [Kubeflow - Launch Experiment](https://raw.githubusercontent.com/kubeflow/pipelines/d343607674a196eb4ba21a29eb56ecccc5af658a/components/kubeflow/katib-launcher/component.yaml)

 / [kubeflow](https://github.com/kubeflow/pipelines/tree/2a1fe45e182666a12e0675cb93accb1e36f908fb/components/kubeflow) / [kfserving](https://github.com/kubeflow/pipelines/tree/2a1fe45e182666a12e0675cb93accb1e36f908fb/components/kubeflow/kfserving) / [Kubeflow - Serve Model using KFServing](https://raw.githubusercontent.com/kubeflow/pipelines/2a1fe45e182666a12e0675cb93accb1e36f908fb/components/kubeflow/kfserving/component.yaml)

 / [kubeflow](https://github.com/kubeflow/pipelines/tree/2923af77be7363d6b670eb0bbf6be3446d35b175/components/kubeflow) / [launcher](https://github.com/kubeflow/pipelines/tree/2923af77be7363d6b670eb0bbf6be3446d35b175/components/kubeflow/launcher) / [Kubeflow - Launch TFJob](https://raw.githubusercontent.com/kubeflow/pipelines/2923af77be7363d6b670eb0bbf6be3446d35b175/components/kubeflow/launcher/component.yaml)

 / [local](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/local) / [confusion_matrix](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/local/confusion_matrix) / [Confusion matrix](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/local/confusion_matrix/component.yaml)

 / [local](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/local) / [roc](https://github.com/kubeflow/pipelines/tree/7d36f48482d93f331664a851842276b733f1686a/components/local/roc) / [ROC curve](https://raw.githubusercontent.com/kubeflow/pipelines/1.4.0-rc.1/components/local/roc/component.yaml)

 / [ml_metrics](https://github.com/kubeflow/pipelines/tree/d4d692e4c2508328961e892acda03453f4b23600/components/ml_metrics) / [Aggregate_regression_metrics](https://github.com/kubeflow/pipelines/tree/d4d692e4c2508328961e892acda03453f4b23600/components/ml_metrics/Aggregate_regression_metrics) / [Aggregate regression metrics](https://raw.githubusercontent.com/kubeflow/pipelines/d4d692e4c2508328961e892acda03453f4b23600/components/ml_metrics/Aggregate_regression_metrics/component.yaml)

 / [ml_metrics](https://github.com/kubeflow/pipelines/tree/9a00eb3c9d56480305f6ee2c601c405e82264f81/components/ml_metrics) / [Calculate_classification_metrics](https://github.com/kubeflow/pipelines/tree/9a00eb3c9d56480305f6ee2c601c405e82264f81/components/ml_metrics/Calculate_classification_metrics) / [from_CSV](https://github.com/kubeflow/pipelines/tree/9a00eb3c9d56480305f6ee2c601c405e82264f81/components/ml_metrics/Calculate_classification_metrics/from_CSV) / [Calculate classification metrics from csv](https://raw.githubusercontent.com/kubeflow/pipelines/9a00eb3c9d56480305f6ee2c601c405e82264f81/components/ml_metrics/Calculate_classification_metrics/from_CSV/component.yaml)

 / [ml_metrics](https://github.com/kubeflow/pipelines/tree/1d8abb7be45fe5a5352d0604da3cac9a288aedc4/components/ml_metrics) / [Calculate_regression_metrics](https://github.com/kubeflow/pipelines/tree/1d8abb7be45fe5a5352d0604da3cac9a288aedc4/components/ml_metrics/Calculate_regression_metrics) / [from_CSV](https://github.com/kubeflow/pipelines/tree/1d8abb7be45fe5a5352d0604da3cac9a288aedc4/components/ml_metrics/Calculate_regression_metrics/from_CSV) / [Calculate regression metrics from csv](https://raw.githubusercontent.com/kubeflow/pipelines/1d8abb7be45fe5a5352d0604da3cac9a288aedc4/components/ml_metrics/Calculate_regression_metrics/from_CSV/component.yaml)

 / [notebooks](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/notebooks) / [Run_notebook_using_papermill](https://github.com/kubeflow/pipelines/tree/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/notebooks/Run_notebook_using_papermill) / [Run notebook using papermill](https://raw.githubusercontent.com/kubeflow/pipelines/b656fbf41e4801c4264ca3cb217a7913ac825a3d/components/notebooks/Run_notebook_using_papermill/component.yaml)

 / [nuclio](https://github.com/kubeflow/pipelines/tree/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio) / [delete](https://github.com/kubeflow/pipelines/tree/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio/delete) / [nuclio delete](https://raw.githubusercontent.com/kubeflow/pipelines/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio/delete/component.yaml)

 / [nuclio](https://github.com/kubeflow/pipelines/tree/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio) / [deploy](https://github.com/kubeflow/pipelines/tree/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio/deploy) / [nuclio deploy](https://raw.githubusercontent.com/kubeflow/pipelines/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio/deploy/component.yaml)

 / [nuclio](https://github.com/kubeflow/pipelines/tree/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio) / [invoker](https://github.com/kubeflow/pipelines/tree/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio/invoker) / [nuclio invoker](https://raw.githubusercontent.com/kubeflow/pipelines/442c80449d4253a66fb247ea345f5f82422c6632/components/nuclio/invoker/component.yaml)

 / [pandas](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas) / [Transform_DataFrame](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas/Transform_DataFrame) / [in_ApacheParquet_format](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas/Transform_DataFrame/in_ApacheParquet_format) / [Pandas Transform DataFrame in ApacheParquet format](https://raw.githubusercontent.com/kubeflow/pipelines/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas/Transform_DataFrame/in_ApacheParquet_format/component.yaml)

 / [pandas](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas) / [Transform_DataFrame](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas/Transform_DataFrame) / [in_CSV_format](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas/Transform_DataFrame/in_CSV_format) / [Pandas Transform DataFrame in CSV format](https://raw.githubusercontent.com/kubeflow/pipelines/cd0e4870e2104c5cda419571938d28533b42167f/components/pandas/Transform_DataFrame/in_CSV_format/component.yaml)

 / [presto](https://github.com/kubeflow/pipelines/tree/1e9524192c21edbce9b101959f940d8b945e61d7/components/presto) / [query](https://github.com/kubeflow/pipelines/tree/1e9524192c21edbce9b101959f940d8b945e61d7/components/presto/query) / [Presto Query](https://raw.githubusercontent.com/kubeflow/pipelines/1e9524192c21edbce9b101959f940d8b945e61d7/components/presto/query/component.yaml)

 / [sample](https://github.com/kubeflow/pipelines/tree/e54a8e3570649bae438b649eac757d4a7e02597a/components/sample) / [keras](https://github.com/kubeflow/pipelines/tree/e54a8e3570649bae438b649eac757d4a7e02597a/components/sample/keras) / [train_classifier](https://github.com/kubeflow/pipelines/tree/e54a8e3570649bae438b649eac757d4a7e02597a/components/sample/keras/train_classifier) / [Keras - Train classifier](https://raw.githubusercontent.com/kubeflow/pipelines/e54a8e3570649bae438b649eac757d4a7e02597a/components/sample/keras/train_classifier/component.yaml)

 / [tables](https://github.com/kubeflow/pipelines/tree/b1c1431eb8d6b7cc63c55f5e828faf9859a50e55/components/tables) / [Remove_header](https://github.com/kubeflow/pipelines/tree/b1c1431eb8d6b7cc63c55f5e828faf9859a50e55/components/tables/Remove_header) / [Remove header](https://raw.githubusercontent.com/kubeflow/pipelines/b1c1431eb8d6b7cc63c55f5e828faf9859a50e55/components/tables/Remove_header/component.yaml)

 / [tensorflow](https://github.com/kubeflow/pipelines/tree/0f4037231fd8a5a163a568d3876d1be0c5da30a6/components/tensorflow) / [tensorboard](https://github.com/kubeflow/pipelines/tree/0f4037231fd8a5a163a568d3876d1be0c5da30a6/components/tensorflow/tensorboard) / [prepare_tensorboard](https://github.com/kubeflow/pipelines/tree/0f4037231fd8a5a163a568d3876d1be0c5da30a6/components/tensorflow/tensorboard/prepare_tensorboard) / [Create Tensorboard visualization](https://raw.githubusercontent.com/kubeflow/pipelines/0f4037231fd8a5a163a568d3876d1be0c5da30a6/components/tensorflow/tensorboard/prepare_tensorboard/component.yaml)

 / [web](https://github.com/kubeflow/pipelines/tree/240543e483076ae718f82c6f280441daa2f041fd/components/web) / [Download](https://github.com/kubeflow/pipelines/tree/240543e483076ae718f82c6f280441daa2f041fd/components/web/Download) / [Download data](https://raw.githubusercontent.com/kubeflow/pipelines/240543e483076ae718f82c6f280441daa2f041fd/components/web/Download/component.yaml)

 / [XGBoost](https://github.com/kubeflow/pipelines/tree/34cb59daaea4f800afae5d968b5efd31eb432291/components/XGBoost) / [Cross_validation_for_regression](https://github.com/kubeflow/pipelines/tree/34cb59daaea4f800afae5d968b5efd31eb432291/components/XGBoost/Cross_validation_for_regression) / [from_CSV](https://github.com/kubeflow/pipelines/tree/34cb59daaea4f800afae5d968b5efd31eb432291/components/XGBoost/Cross_validation_for_regression/from_CSV) / [Xgboost 5 fold cross validation for regression](https://raw.githubusercontent.com/kubeflow/pipelines/34cb59daaea4f800afae5d968b5efd31eb432291/components/XGBoost/Cross_validation_for_regression/from_CSV/component.yaml)

 / [XGBoost](https://github.com/kubeflow/pipelines/tree/ea94251143f300fafed8950a1b4ba0a6b6065094/components/XGBoost) / [Predict](https://github.com/kubeflow/pipelines/tree/ea94251143f300fafed8950a1b4ba0a6b6065094/components/XGBoost/Predict) / [Xgboost predict](https://raw.githubusercontent.com/kubeflow/pipelines/ea94251143f300fafed8950a1b4ba0a6b6065094/components/XGBoost/Predict/component.yaml)

 / [XGBoost](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost) / [Predict](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost/Predict) / [from_ApacheParquet](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost/Predict/from_ApacheParquet) / [Xgboost predict](https://raw.githubusercontent.com/kubeflow/pipelines/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost/Predict/from_ApacheParquet/component.yaml)

 / [XGBoost](https://github.com/kubeflow/pipelines/tree/ea94251143f300fafed8950a1b4ba0a6b6065094/components/XGBoost) / [Train](https://github.com/kubeflow/pipelines/tree/ea94251143f300fafed8950a1b4ba0a6b6065094/components/XGBoost/Train) / [Xgboost train](https://raw.githubusercontent.com/kubeflow/pipelines/ea94251143f300fafed8950a1b4ba0a6b6065094/components/XGBoost/Train/component.yaml)

 / [XGBoost](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost) / [Train](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost/Train) / [from_ApacheParquet](https://github.com/kubeflow/pipelines/tree/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost/Train/from_ApacheParquet) / [Xgboost train](https://raw.githubusercontent.com/kubeflow/pipelines/cd0e4870e2104c5cda419571938d28533b42167f/components/XGBoost/Train/from_ApacheParquet/component.yaml)

 / [XGBoost](https://github.com/kubeflow/pipelines/tree/acb50e7d12183e50307fee054f478aab0b27fadd/components/XGBoost) / [Train_and_cross-validate_regression](https://github.com/kubeflow/pipelines/tree/acb50e7d12183e50307fee054f478aab0b27fadd/components/XGBoost/Train_and_cross-validate_regression) / [from_CSV](https://github.com/kubeflow/pipelines/tree/acb50e7d12183e50307fee054f478aab0b27fadd/components/XGBoost/Train_and_cross-validate_regression/from_CSV) / [Xgboost train and cv regression on csv](https://raw.githubusercontent.com/kubeflow/pipelines/acb50e7d12183e50307fee054f478aab0b27fadd/components/XGBoost/Train_and_cross-validate_regression/from_CSV/component.yaml)

 / [XGBoost](https://github.com/kubeflow/pipelines/tree/8d373e77a48d0517957028184937b5e2f914f05b/components/XGBoost) / [Train_regression_and_calculate_metrics](https://github.com/kubeflow/pipelines/tree/8d373e77a48d0517957028184937b5e2f914f05b/components/XGBoost/Train_regression_and_calculate_metrics) / [from_CSV](https://github.com/kubeflow/pipelines/tree/8d373e77a48d0517957028184937b5e2f914f05b/components/XGBoost/Train_regression_and_calculate_metrics/from_CSV) / [Xgboost train regression and calculate metrics on csv](https://raw.githubusercontent.com/kubeflow/pipelines/8d373e77a48d0517957028184937b5e2f914f05b/components/XGBoost/Train_regression_and_calculate_metrics/from_CSV/component.yaml)

